@@ -135,16 +135,25 @@ static struct densities {
     char *name;
 } density_tbl[] = {
     /* clang-format off */
+    /* Information taken from https://www.t10.org/ftp/x3t9.2/document.93/93-013r0.pdf:
+     * NZRI: Non-Return to Zero, change on ones
+     * GCR: Group Code Recording
+     * PE: Phase Encoding
+     * IMFM: Inverted Modified Frequency Modulation
+     * MFM: Modified Frequency Modulation
+     * DDS: DAT Data Storage
+     * RLL: Run Length Limited
+     */
     { 0x00, "default"                        },
-    { 0x01, "NRZI (800 bpi)"                 },
-    { 0x02, "PE (1600 bpi)"                  },
-    { 0x03, "GCR (6250 bpi)"                 },
+    { 0x01, "NRZI (800 bpi) 9 Track Reel"    },
+    { 0x02, "PE (1600 bpi) 9 Track Reel"     },
+    { 0x03, "GCR (6250 bpi) 9 Track Reel"    },
     { 0x04, "QIC-11"                         },
     { 0x05, "QIC-45/60 (GCR, 8000 bpi)"      },
-    { 0x06, "PE (3200 bpi)"                  },
+    { 0x06, "PE (3200 bpi) 9 Track Reel"     },
     { 0x07, "IMFM (6400 bpi)"                },
     { 0x08, "GCR (8000 bpi)"                 },
-    { 0x09, "GCR (37871 bpi)"                },
+    { 0x09, "3480/3490E, GCR (37871 bpi)"    },
     { 0x0a, "MFM (6667 bpi)"                 },
     { 0x0b, "PE (1600 bpi)"                  },
     { 0x0c, "GCR (12960 bpi)"                },
@@ -196,20 +205,27 @@ static struct densities {
     { 0x4c, "T10000C"                        },
     { 0x4d, "T10000D"                        },
     { 0x51, "IBM 3592 J1A"                   },
-    { 0x52, "IBM 3592 E05"                   },
-    { 0x53, "IBM 3592 E06"                   },
-    { 0x54, "IBM 3592 E07"                   },
-    { 0x55, "IBM 3592 E08"                   },
+    { 0x52, "IBM 3592 E05 (TS1120)"          },
+    { 0x53, "IBM 3592 E06 (TS1130)"          },
+    { 0x54, "IBM 3592 E07 (TS1140)"          },
+    { 0x55, "IBM 3592 E08 (TS1150)"          },
+    { 0x56, "IBM 3592 55F (TS1155)"          },
+    { 0x57, "IBM 3592 60F (TS1160)"          },
     { 0x58, "LTO-5"                          },
+    { 0x59, "IBM 3592 70F (TS1170)"          },
     { 0x5a, "LTO-6"                          },
     { 0x5c, "LTO-7"                          },
     { 0x5d, "LTO-7-M8"                       },
     { 0x5e, "LTO-8"                          },
+    { 0x60, "LTO-9"                          },
     { 0x71, "IBM 3592 J1A, encrypted"        },
     { 0x72, "IBM 3592 E05, encrypted"        },
     { 0x73, "IBM 3592 E06, encrypted"        },
     { 0x74, "IBM 3592 E07, encrypted"        },
     { 0x75, "IBM 3592 E08, encrypted"        },
+    { 0x76, "IBM 3592 55F, encrypted"        },
+    { 0x77, "IBM 3592 60F, encrypted"        },
+    { 0x79, "IBM 3592 70F, encrypted"        },
     { 0x80, "DLT 15GB uncomp. or Ecrix"      },
     { 0x81, "DLT 15GB compressed"            },
     { 0x82, "DLT 20GB uncompressed"          },
@@ -224,7 +240,7 @@ static struct densities {
     { 0x90, "SDLT110 uncompr/EXB-8205 compr" },
     { 0x91, "SDLT110 compressed"             },
     { 0x92, "SDLT160 uncompressed"           },
-    { 0x93, "SDLT160 comprssed"              }
+    { 0x93, "SDLT160 compressed"             }
     /* clang-format on */
 };
 
@@ -249,6 +265,7 @@ static struct booleans {
     { "can-partitions", MT_ST_CAN_PARTITIONS, "drive can handle partitioned tapes"           },
     { "scsi2logical",   MT_ST_SCSI2LOGICAL,   "logical block addresses used with SCSI-2"     },
     { "no-wait",        MT_ST_NOWAIT,         "immediate mode for rewind, etc."              },
+    { "weof-no-wait",	MT_ST_NOWAIT_EOF,     "immediate mode for writing filemarks"	     },
 #ifdef MT_ST_SYSV
     { "sysv",           MT_ST_SYSV,           "enable the SystemV semantics"                 },
 #endif
@@ -687,7 +704,7 @@ static int do_status(int mtfd,
 #define TAPE_NR(minor)                              \
     ((((minor) & ~255) >> (ST_NBR_MODE_BITS + 1)) | \
      ((minor) & ((1 << ST_MODE_SHIFT) - 1)))
-#define TAPE_MODE(minor) (((minor)&ST_MODE_MASK) >> ST_MODE_SHIFT)
+#define TAPE_MODE(minor) (((minor) & ST_MODE_MASK) >> ST_MODE_SHIFT)
 static const char *st_formats[] = { "",  "r", "k", "s", "l", "t", "o", "u",
                                     "m", "v", "p", "x", "a", "y", "q", "z" };
 
@@ -775,6 +792,6 @@ static void test_error(int mtfd, cmdef_tr *cmd)
     if ((cmd->error_tests & ET_ONLINE) && !GMT_ONLINE(status.mt_gstat))
         fprintf(stderr,
                 "mt: The device is offline (not powered on, no tape ?).\n");
-    if ((cmd->error_tests & ET_WPROT) && !GMT_WR_PROT(status.mt_gstat))
+    if ((cmd->error_tests & ET_WPROT) && GMT_WR_PROT(status.mt_gstat))
         fprintf(stderr, "mt: The tape is write-protected.\n");
 }
